@@ -1,3 +1,4 @@
-from salure_helpers.sap.base import Base
+from salure_helpers.sap.sap import SAP
+from salure_helpers.sap.base_functions import BaseFunctions
 from salure_helpers.sap.delimit_endpoints import DelimitEndpoints
 from salure_helpers.sap.post_endpoints import PostEndpoints
